@@ -1,4 +1,6 @@
+#ifdef ENABLE_NOTIFY
 #include <libnotify/notify.h>
+#endif
 
 #include "ui/vkgallery.h"
 
@@ -26,8 +28,15 @@ int main(int argc, char *argv[])
 	DATAPREFIX"/qt4/translations/");
     a.installTranslator(&commontr);
 
+    QTranslator qtTranslator;
+    qtTranslator.load("qt_" + QLocale::system().name(),
+                      QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+    a.installTranslator(&qtTranslator);
+
+#ifdef ENABLE_NOTIFY
     /* Init libnotify library */
     notify_init(APP_NAME);
+#endif
 
     VKGallery w;
     w.showMaximized();
